@@ -63,6 +63,7 @@ import java.security.PublicKey;
 import java.security.UnrecoverableKeyException;
 import java.security.cert.Certificate;
 import java.security.cert.CertificateException;
+import java.util.Enumeration;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 import java.util.regex.Matcher;
@@ -241,8 +242,8 @@ public class S3FileStorageFactory implements FileStorageFactoryCandidate {
             inputStream = new FileInputStream(pathToKeyStore);
             KeyStore keyStore = KeyStore.getInstance("PKCS12");
             keyStore.load(inputStream, passwordChars);
-            while (keyStore.aliases().hasMoreElements()) {
-                String alias = keyStore.aliases().nextElement();
+            for (Enumeration<String> aliases = keyStore.aliases(); aliases.hasMoreElements();) {
+                String alias = aliases.nextElement();
                 if (keyStore.isKeyEntry(alias)) {
                     Key key = keyStore.getKey(alias, passwordChars);
                     if (null != key && PrivateKey.class.isInstance(key)) {
@@ -254,17 +255,17 @@ public class S3FileStorageFactory implements FileStorageFactoryCandidate {
                 }
             }
         } catch (FileNotFoundException e) {
-            throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create("Error reading " + pathToKeyStore);
+            throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(e, "Error reading " + pathToKeyStore);
         } catch (KeyStoreException e) {
-            throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create("Error reading " + pathToKeyStore);
+            throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(e, "Error reading " + pathToKeyStore);
         } catch (NoSuchAlgorithmException e) {
-            throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create("Error reading " + pathToKeyStore);
+            throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(e, "Error reading " + pathToKeyStore);
         } catch (CertificateException e) {
-            throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create("Error reading " + pathToKeyStore);
+            throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(e, "Error reading " + pathToKeyStore);
         } catch (IOException e) {
-            throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create("Error reading " + pathToKeyStore);
+            throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(e, "Error reading " + pathToKeyStore);
         } catch (UnrecoverableKeyException e) {
-            throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create("Error reading " + pathToKeyStore);
+            throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(e, "Error reading " + pathToKeyStore);
         } finally {
             Streams.close(inputStream);
         }
@@ -272,7 +273,7 @@ public class S3FileStorageFactory implements FileStorageFactoryCandidate {
             throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create("No private key found in " + pathToKeyStore);
         }
         if (null == publicKey) {
-            throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create("No private key found in " + pathToKeyStore);
+            throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create("No public key found in " + pathToKeyStore);
         }
         return new KeyPair(publicKey, privateKey);
     }
